# LocalAuthUpstreamConfig

Local authentication upstream identity providers for example an Agilicus Agent running onsite.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**upstream_id** | **str** | Uniquely identifies the upstream resource providing the local authentication for instance an Agilicus Agent Connector ID. | 
**upstream_domain_name** | **str** | If The domain this local upstream provides is incorrect, use this to overide it to some known correct value | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


